@@ -1,62 +1,16 @@
 package Data::Serializer::Data::Denter;
 BEGIN { @Data::Serializer::Data::Denter::ISA = qw(Data::Serializer) }
 
-
+use warnings;
 use strict;
 
 use Carp;
 use Data::Denter;
 
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-
-require Exporter;
-require AutoLoader;
-
-@ISA = qw(Exporter AutoLoader);
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-@EXPORT = qw(
-	
-);
-$VERSION = '0.01';
+use vars qw($VERSION @ISA);
 
 
-# Preloaded methods go here.
-
-# Autoload methods go after =cut, and are processed by the autosplit program.
-
-1;
-__END__
-# Below is the stub of documentation for your module. You better edit it!
-
-=head1 NAME
-
-Data::Serializer::Data::Denter - Creates bridge between Data::Serializer and Data::Denter
-
-=head1 SYNOPSIS
-
-  use Data::Serializer::Data::Denter;
-
-=head1 DESCRIPTION
-
-Module is used internally to Data::Serializer 
-
-=head1 AUTHOR
-
-Neil Neely <neil@neely.cx>
-
-=head1 COPYRIGHT
-
-  Copyright 2002 by Neil Neely.  All rights reserved.
-  This program is free software; you can redistribute it
-  and/or modify it under the same terms as Perl itself.
-
-=head1 SEE ALSO
-
-perl(1), Data::Serializer(3), Data::Denter(3).
-
-=cut
+$VERSION = '0.02';
 
 #
 # Create a Data::Denter serializer object.
@@ -78,3 +32,45 @@ sub deserialize {
   return Data::Denter::Undent($val);
 }
 
+1;
+__END__
+
+# 
+
+=head1 NAME
+
+Data::Serializer::Data::Denter - Creates bridge between Data::Serializer and Data::Denter
+
+=head1 SYNOPSIS
+
+  use Data::Serializer::Data::Denter;
+
+=head1 DESCRIPTION
+
+Module is used internally to Data::Serializer 
+
+
+=over 4
+
+=item B<serialize> - Wrapper to normalize serializer method name
+
+=item B<deserialize> - Wrapper to normalize deserializer method name
+
+=back
+
+=head1 AUTHOR
+
+Neil Neely <neil@neely.cx>
+
+=head1 COPYRIGHT
+
+  Copyright 2002 by Neil Neely.  All rights reserved.
+  This program is free software; you can redistribute it
+  and/or modify it under the same terms as Perl itself.
+
+=head1 SEE ALSO
+
+perl(1), Data::Serializer(3), Data::Denter(3).
+
+=cut
+
