@@ -1,31 +1,28 @@
 package Data::Serializer::Data::Taxi;
 BEGIN { @Data::Serializer::Data::Taxi::ISA = qw(Data::Serializer) }
 
-
+use warnings;
 use strict;
 use Data::Taxi;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
+use vars qw($VERSION @ISA);
 
-require Exporter;
-require AutoLoader;
-
-@ISA = qw(Exporter AutoLoader);
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-@EXPORT = qw(
-	
-);
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 
-# Preloaded methods go here.
+sub serialize {
+    return Data::Taxi::freeze($_[1]);
+}
+
+sub deserialize {
+    my ($obj) = Data::Taxi::thaw($_[1]);
+    return $obj;
+}
+
 
-# Autoload methods go after =cut, and are processed by the autosplit program.
 
 1;
 __END__
-# Below is the stub of documentation for your module. You better edit it!
+# 
 
 =head1 NAME
 
@@ -39,6 +36,15 @@ Data::Serializer::Data::Taxi - Creates bridge between Data::Serializer and Data:
 
 Module is used internally to Data::Serializer
 
+
+=over 4
+
+=item B<serialize> - Wrapper to normalize serializer method name
+
+=item B<deserialize> - Wrapper to normalize deserializer method name
+
+=back
+
 =head1 AUTHOR
 
 Neil Neely <neil@neely.cx>
@@ -54,12 +60,3 @@ Neil Neely <neil@neely.cx>
 perl(1), Data::Serializer(3), Data::Taxi(3).
 
 =cut
-
-sub serialize {
-    return Data::Taxi::freeze($_[1]);
-}
-
-sub deserialize {
-    my ($obj) = Data::Taxi::thaw($_[1]);
-    return $obj;
-}
